# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.raid_groups_api import RAIDGroupsApi  # noqa: E501
from Vpsa.rest import ApiException


class TestRAIDGroupsApi(unittest.TestCase):
    """RAIDGroupsApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.raid_groups_api.RAIDGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_hot_spare_to_raid_group(self):
        """Test case for add_hot_spare_to_raid_group

        """
        pass

    def test_create_raid_group(self):
        """Test case for create_raid_group

        """
        pass

    def test_delete_raid_group(self):
        """Test case for delete_raid_group

        """
        pass

    def test_get_drives_in_raid_group(self):
        """Test case for get_drives_in_raid_group

        """
        pass

    def test_get_free_raid_groups(self):
        """Test case for get_free_raid_groups

        """
        pass

    def test_get_raid_group(self):
        """Test case for get_raid_group

        """
        pass

    def test_get_raid_group_performance(self):
        """Test case for get_raid_group_performance

        """
        pass

    def test_pause_raid_group_media_scan(self):
        """Test case for pause_raid_group_media_scan

        """
        pass

    def test_remove_hot_spare_from_raid_group(self):
        """Test case for remove_hot_spare_from_raid_group

        """
        pass

    def test_rename_raid_group(self):
        """Test case for rename_raid_group

        """
        pass

    def test_repair_raid_group(self):
        """Test case for repair_raid_group

        """
        pass

    def test_show_raid_groups(self):
        """Test case for show_raid_groups

        """
        pass

    def test_start_raid_group_media_scan(self):
        """Test case for start_raid_group_media_scan

        """
        pass

    def test_update_raid_group_resync_speed(self):
        """Test case for update_raid_group_resync_speed

        """
        pass


if __name__ == '__main__':
    unittest.main()
