# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20058ResponseUsageUsageSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'billed_amount': 'float',
        'billed_units': 'float',
        'subcategory': 'str',
        'type': 'str',
        'unit': 'str'
    }

    attribute_map = {
        'category': 'category',
        'billed_amount': 'billed_amount',
        'billed_units': 'billed_units',
        'subcategory': 'subcategory',
        'type': 'type',
        'unit': 'unit'
    }

    def __init__(self, category=None, billed_amount=None, billed_units=None, subcategory=None, type=None, unit=None, _configuration=None):  # noqa: E501
        """InlineResponse20058ResponseUsageUsageSummary - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._category = None
        self._billed_amount = None
        self._billed_units = None
        self._subcategory = None
        self._type = None
        self._unit = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if billed_amount is not None:
            self.billed_amount = billed_amount
        if billed_units is not None:
            self.billed_units = billed_units
        if subcategory is not None:
            self.subcategory = subcategory
        if type is not None:
            self.type = type
        if unit is not None:
            self.unit = unit

    @property
    def category(self):
        """Gets the category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this InlineResponse20058ResponseUsageUsageSummary.


        :param category: The category of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def billed_amount(self):
        """Gets the billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: float
        """
        return self._billed_amount

    @billed_amount.setter
    def billed_amount(self, billed_amount):
        """Sets the billed_amount of this InlineResponse20058ResponseUsageUsageSummary.


        :param billed_amount: The billed_amount of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: float
        """

        self._billed_amount = billed_amount

    @property
    def billed_units(self):
        """Gets the billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: float
        """
        return self._billed_units

    @billed_units.setter
    def billed_units(self, billed_units):
        """Sets the billed_units of this InlineResponse20058ResponseUsageUsageSummary.


        :param billed_units: The billed_units of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: float
        """

        self._billed_units = billed_units

    @property
    def subcategory(self):
        """Gets the subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._subcategory

    @subcategory.setter
    def subcategory(self, subcategory):
        """Sets the subcategory of this InlineResponse20058ResponseUsageUsageSummary.


        :param subcategory: The subcategory of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._subcategory = subcategory

    @property
    def type(self):
        """Gets the type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20058ResponseUsageUsageSummary.


        :param type: The type of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """Gets the unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501


        :return: The unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this InlineResponse20058ResponseUsageUsageSummary.


        :param unit: The unit of this InlineResponse20058ResponseUsageUsageSummary.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20058ResponseUsageUsageSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20058ResponseUsageUsageSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20058ResponseUsageUsageSummary):
            return True

        return self.to_dict() != other.to_dict()
