# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array - All Flash Array VPSA  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03.1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class ConfigureFileAccessAudit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audit_enable': 'str',
        'audit_vol_pool_name': 'str',
        'obs_dest': 'str',
        'operations': 'str',
        'force': 'str'
    }

    attribute_map = {
        'audit_enable': 'audit_enable',
        'audit_vol_pool_name': 'audit_vol_pool_name',
        'obs_dest': 'obs_dest',
        'operations': 'operations',
        'force': 'force'
    }

    def __init__(self, audit_enable=None, audit_vol_pool_name=None, obs_dest=None, operations=None, force=None, _configuration=None):  # noqa: E501
        """ConfigureFileAccessAudit - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._audit_enable = None
        self._audit_vol_pool_name = None
        self._obs_dest = None
        self._operations = None
        self._force = None
        self.discriminator = None

        self.audit_enable = audit_enable
        self.audit_vol_pool_name = audit_vol_pool_name
        if obs_dest is not None:
            self.obs_dest = obs_dest
        self.operations = operations
        if force is not None:
            self.force = force

    @property
    def audit_enable(self):
        """Gets the audit_enable of this ConfigureFileAccessAudit.  # noqa: E501

        'YES' to enable or resume, 'NO' to pause file access auditing.  # noqa: E501

        :return: The audit_enable of this ConfigureFileAccessAudit.  # noqa: E501
        :rtype: str
        """
        return self._audit_enable

    @audit_enable.setter
    def audit_enable(self, audit_enable):
        """Sets the audit_enable of this ConfigureFileAccessAudit.

        'YES' to enable or resume, 'NO' to pause file access auditing.  # noqa: E501

        :param audit_enable: The audit_enable of this ConfigureFileAccessAudit.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and audit_enable is None:
            raise ValueError("Invalid value for `audit_enable`, must not be `None`")  # noqa: E501

        self._audit_enable = audit_enable

    @property
    def audit_vol_pool_name(self):
        """Gets the audit_vol_pool_name of this ConfigureFileAccessAudit.  # noqa: E501

        The pool name for the auditing volume. Only required for Enable or resume.  # noqa: E501

        :return: The audit_vol_pool_name of this ConfigureFileAccessAudit.  # noqa: E501
        :rtype: str
        """
        return self._audit_vol_pool_name

    @audit_vol_pool_name.setter
    def audit_vol_pool_name(self, audit_vol_pool_name):
        """Sets the audit_vol_pool_name of this ConfigureFileAccessAudit.

        The pool name for the auditing volume. Only required for Enable or resume.  # noqa: E501

        :param audit_vol_pool_name: The audit_vol_pool_name of this ConfigureFileAccessAudit.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and audit_vol_pool_name is None:
            raise ValueError("Invalid value for `audit_vol_pool_name`, must not be `None`")  # noqa: E501

        self._audit_vol_pool_name = audit_vol_pool_name

    @property
    def obs_dest(self):
        """Gets the obs_dest of this ConfigureFileAccessAudit.  # noqa: E501

        ID of remote object storage destination.  # noqa: E501

        :return: The obs_dest of this ConfigureFileAccessAudit.  # noqa: E501
        :rtype: str
        """
        return self._obs_dest

    @obs_dest.setter
    def obs_dest(self, obs_dest):
        """Sets the obs_dest of this ConfigureFileAccessAudit.

        ID of remote object storage destination.  # noqa: E501

        :param obs_dest: The obs_dest of this ConfigureFileAccessAudit.  # noqa: E501
        :type: str
        """

        self._obs_dest = obs_dest

    @property
    def operations(self):
        """Gets the operations of this ConfigureFileAccessAudit.  # noqa: E501

        Names of file access operations to audit. Only required for Enable or resume.  # noqa: E501

        :return: The operations of this ConfigureFileAccessAudit.  # noqa: E501
        :rtype: str
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        """Sets the operations of this ConfigureFileAccessAudit.

        Names of file access operations to audit. Only required for Enable or resume.  # noqa: E501

        :param operations: The operations of this ConfigureFileAccessAudit.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and operations is None:
            raise ValueError("Invalid value for `operations`, must not be `None`")  # noqa: E501

        self._operations = operations

    @property
    def force(self):
        """Gets the force of this ConfigureFileAccessAudit.  # noqa: E501

        Use in case a confirmation is required.  # noqa: E501

        :return: The force of this ConfigureFileAccessAudit.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this ConfigureFileAccessAudit.

        Use in case a confirmation is required.  # noqa: E501

        :param force: The force of this ConfigureFileAccessAudit.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConfigureFileAccessAudit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigureFileAccessAudit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigureFileAccessAudit):
            return True

        return self.to_dict() != other.to_dict()
